Name:           avogadro2-libs
Version:        1.90.0
Release:        7%{?dist}
Summary:        Avogadro2 libraries

# BSD is main license
# MIT is the license of jsoncpp.a
License:        BSD and MIT
URL:            http://avogadro.openmolecules.net/
Source0:        https://github.com/OpenChemistry/avogadrolibs/archive/%{version}.tar.gz#/avogadrolibs-%{version}.tar.gz

# Fix compatibility with gcc7
Patch0:         %{name}-fix_gcc7_compatibility.patch

# Fix reported path
Patch1:         %{name}-fix_AvogadroLibsConfig.patch

# Set installation path of jsoncpp.a file
Patch2:         %{name}-set_jsoncpp_path.patch

# Set installation path of Python files
Patch3:         %{name}-set_pythonpath.patch

BuildRequires:  boost-devel
BuildRequires:  python%{python3_pkgversion}-devel
%if 0%{?fedora}
BuildRequires:  boost-python3-devel
%endif
BuildRequires:  cmake, chrpath
BuildRequires:  gcc-c++, doxygen
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(openbabel-2.0)
BuildRequires:  mesa-libGLU-devel
BuildRequires:  hdf5-devel
BuildRequires:  spglib-devel, molequeue-devel
BuildRequires:  qt5-qtbase-devel, qt5-qttools-devel

Provides: %{name}-static = %{version}-%{release}
Provides: jsoncpp-static
%{?python_provide:%python_provide python%{python3_pkgversion}-%{name}}

%description
Avogadro libraries provide 3D rendering, visualization, analysis
and data processing useful in computational chemistry, molecular modeling,
bioinformatics, materials science, and related areas.

%package  devel
Summary:  Development files of %{name}
Requires: qt5-qtbase-devel
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
This package contains libraries and header files for developing
applications that use %{name}.

%package doc
Summary: HTML documentation of %{name}
BuildArch: noarch
%description doc
HTML documentation of %{name}.

%prep
%setup -q -n avogadrolibs-%{version}
%patch0 -p0
%patch1 -p0
%patch2 -p0
%patch3 -p0

%build
mkdir build && pushd build
export LDFLAGS="%{__global_ldflags} -Wl,--as-needed"
%cmake -DCMAKE_BUILD_TYPE:STRING=Release \
 -DCMAKE_INSTALL_INCLUDEDIR:PATH=%{_includedir}/avogadro2 \
 -Wno-dev \
 -DENABLE_GLSL:BOOL=ON \
 -DENABLE_PYTHON:BOOL=ON  \
 -DPYTHON_EXECUTABLE:FILEPATH=%{__python3} \
 -DPYTHON_VERSION:STRING=%{python3_version} \
%if 0%{?fedora}
 -DUSE_BOOST_PYTHON:BOOL=ON \
%else
 -DUSE_BOOST_PYTHON:BOOL=OFF \
%endif
 -DENABLE_RPATH:BOOL=OFF \
 -DENABLE_TESTING:BOOL=OFF \
 -DUSE_MOLEQUEUE:BOOL=ON \
 -DUSE_VTK:BOOL=OFF \
 -DUSE_HDF5:BOOL=ON \
 -DSPGLIB_LIBRARY:FILEPATH=%{_libdir}/libsymspg.so \
 -DBUILD_GPL_PLUGINS:BOOL=ON \
 -DBUILD_STATIC_PLUGINS:BOOL=ON \
 -DBUILD_DOCUMENTATION:BOOL=ON ..

%make_build

pushd docs
doxygen
popd

%install
%make_install -C build

sed -i -e '1i#!%{__python3}' %{buildroot}%{python3_sitearch}/avogadro2/scripts/inputGenerators/*.py
sed -i -e '1i#!%{__python3}' %{buildroot}%{python3_sitearch}/avogadro2/scripts/formatScripts/*.py

chrpath -d %{buildroot}%{_libdir}/lib*.so
rm -rf %{buildroot}%{_datadir}/doc

%check
pushd build
#ctest -VV

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc README.md
%license COPYING
%{_libdir}/lib*.so
%{_libdir}/avogadro2/
%{python3_sitearch}/avogadro2/

%files devel
%{_includedir}/avogadro2/
%{_libdir}/cmake/avogadrolibs/

%files doc
%doc README.md build/docs/html
%license COPYING

%changelog
* Thu Jun 22 2017 Antonio Trande <sagitter@fedoraproject.org> - 1.90.0-7
- Modified for epel builds

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.90.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Mon Mar 13 2017 Antonio Trande <sagitter@fedoraproject.org> - 1.90.0-5
- Add ld scriptlets

* Sun Mar 12 2017 Antonio Trande <sagitter@fedoraproject.org> - 1.90.0-4
- Set python3 installation directory

* Sun Mar 12 2017 Antonio Trande <sagitter@fedoraproject.org> - 1.90.0-3
- Move jsoncpp.a into the private lib directory

* Sat Mar 11 2017 Antonio Trande <sagitter@fedoraproject.org> - 1.90.0-2
- Use default paths

* Sat Mar 11 2017 Antonio Trande <sagitter@fedoraproject.org> - 1.90.0-1
- Initial package
